@@ -34,7 +34,10 @@ isi2df<-function(D){
   ## Bibliographic data frame initialization
   DATA=data.frame(matrix(NA,nP,length(uniqueTag)))
   names(DATA)=uniqueTag
-
+  
+  ## Fields which need to be collapsed with ";" 
+  specialSep=c("AU","AF","CR","C1","RP")
+  
   for (i in 1:nP){
     if (i%%100==0 | i==nP) cat("Articles extracted  ",i,"\n")
     iStart=Papers[i]
@@ -43,7 +46,11 @@ isi2df<-function(D){
     pTag=iStart+which(regexpr("  ",D[Seq])==1)-1
 
     for (j in uniqueTag){
-
+      
+      ## choose the correct separator for the current field
+      if (j %in% specialSep){sep=";"}else{sep=" "}
+      #####################################################
+      
       indTag=iStart+which(regexpr(j,D[Seq])==1)-1
       if (length(indTag)>0){
         it=0
@@ -51,17 +58,17 @@ isi2df<-function(D){
           if (sum(pTag>(indTag+it))==0){break}
           if (pTag[pTag>indTag+it][1]-(indTag+it)==1){it=it+1} else {break}}
 
-        DATA[[j]][i]=paste(D[indTag:(indTag+it)],collapse=";")
+        DATA[[j]][i]=paste(D[indTag:(indTag+it)],collapse=sep)
         DATA[[j]][i]=substr(DATA[[j]][i],4,nchar(DATA[[j]][i]))} else {DATA[[j]][i]=NA}
     }
   }
 
   
-  
-  if ("AB" %in% uniqueTag){DATA$AB=gsub(";\\s+"," ",DATA$AB)}
-  if ("TI" %in% uniqueTag){DATA$TI=gsub(";\\s+"," ",DATA$TI)}
-  
   DATA <- data.frame(lapply(DATA,toupper),stringsAsFactors = FALSE)
+  
+  ## remove extra spaces
+  DATA <- data.frame(lapply(DATA,function(x){x=gsub("\\s+", " ", x)}),stringsAsFactors = FALSE)
+  
   DATA$UT=gsub("WOS:","ISI",DATA$UT)
   
   if ("PY" %in% names(DATA)){DATA$PY=as.numeric(DATA$PY)}
