@@ -75,15 +75,19 @@ thematicMap <- function(Net, NetMatrix, S=NULL, minfreq=5){
 
 ### centrality and density
   label_cluster=unique(groups)
+  word_cluster=words[groups]
   centrality=c()
   density=c()
   labels=list()
   
-  df_lab=data.frame(sC=sC,words=words,groups=groups)
-  df_lab$color=color
+  df_lab=data.frame(sC=sC,words=words,groups=groups,color=color,cluster_label="NA",stringsAsFactors = FALSE)
+  
   color=c()
   for (i in label_cluster){
     ind=which(groups==i)
+    w=df_lab$words[ind]
+    wi=which.max(df_lab$sC[ind])
+    df_lab$cluster_label[ind]=paste(w[wi[1:min(c(length(wi),3))]],collapse=";",sep="")
     centrality=c(centrality,sum(sEij[ind,-ind]))
     density=c(density,sum(sEij[ind,ind])/length(ind)*100)
     df_lab_g=df_lab[ind,]
@@ -93,7 +97,7 @@ thematicMap <- function(Net, NetMatrix, S=NULL, minfreq=5){
     labels[[length(labels)+1]]=paste(df_lab_g$words[1:k],collapse = ";")
     color=c(color,df_lab$color[ind[1]])
   }
-
+  #df_lab$cluster_label=gsub(";NA;",";",df_lab$cluster_label)
   centrality=centrality*10
   df=data.frame(centrality=centrality,density=density,rcentrality=rank(centrality),rdensity=rank(density),label=label_cluster,color=color)
   df$name=unlist(labels)
@@ -105,21 +109,21 @@ thematicMap <- function(Net, NetMatrix, S=NULL, minfreq=5){
   meandens=mean(df$rdensity)
   meancentr=mean(df$rcentrality)
   df=df[df$freq>=minfreq,]
-  
+
   g=ggplot(df, aes(x=df$rcentrality, y=df$rdensity)) +
     geom_point(aes(size=log(as.numeric(df$freq))),shape=20,col=df$color)     # Use hollow circles
-  g=g+geom_label_repel(aes(label=ifelse(df$freq>1,unlist(df$name),'')),size=3,angle=0)+ geom_hline(yintercept = meandens,linetype=2) +
+  g=g+geom_label_repel(aes(label=ifelse(df$freq>1,unlist(tolower(df$name)),'')),size=3,angle=0)+ geom_hline(yintercept = meandens,linetype=2) +
     geom_vline(xintercept = meancentr,linetype=2) + theme(legend.position="none") +
     scale_radius(range=c(1, 50))+labs(x = "Centrality", y = "Density")+
     theme(axis.text.x=element_blank(),
         axis.ticks.x=element_blank(),
         axis.text.y=element_blank(),
         axis.ticks.y=element_blank())
-#plot(g)
-  names(df_lab)=c("Occurrences", "Words", "Cluster", "Color")
+
+  names(df_lab)=c("Occurrences", "Words", "Cluster", "Color","Cluster_Label")
   words=df_lab[order(df_lab$Cluster),]
   words=words[!is.na(words$Color),]
   row.names(df)=NULL
-  results=list(map=g, clusters=df, words=words)
+  results=list(map=g, clusters=df, words=words,nclust=dim(df)[1])
 return(results)
 }
\ No newline at end of file
